<?php
/**
 * weeblrAMP - Accelerated Mobile Pages for Wordpress
 *
 * @author                  weeblrPress
 * @copyright               (c) WeeblrPress - Weeblr,llc - 2020
 * @package                 AMP on WordPress - weeblrAMP CE
 * @license                 http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @version                 1.12.5.783
 *
 * 2020-05-19
 */

// Security check to ensure this file is being included by a parent file.
defined( 'WEEBLRAMP_EXEC' ) || die;

/**
 * Settings definition for weeblrAMP
 *
 * Used by class WeeblrampConfig_System
 */
return array(

	// List of plugins that should not be shown to user for maybe disabling ------------
	array(
		'name'    => 'plugins_lists',

		// List of plugins to hide
		'content' => array(
			'plugins.do_not_disable_on_amp' => array(
				'name'    => 'plugins.do_not_disable_on_amp',
				'default' => array(
					'weeblramp/weeblramp.php',
					'weeblramp-theme-teal/teal.php',
					'weeblramp-theme-wc/wc.php',
					'weeblramp-theme-edd/edd.php',

					// caching
					'wp-super-cache/wp-cache.php'
				)
			),
		)
	),

	// List configuration pages --------------------------------------------------------
	array(
		'name'    => 'config_pages',

		// options in transients group
		'content' => array(
			'config.lists.pages'   => array(
				'name'    => 'config.lists.pages',
				'default' => array(
					'weeblramp-settings',
					'weeblramp-customize'
				)
			),
			'config.lists.objects' => array(
				'name'    => 'config.lists.objects',
				'default' => array(
					'weeblramp.config.user',
					'weeblramp.config.customize'
				)
			),
		)
	),

	// List of custm rewrite rules -----------------------------------------------------
	array(
		'name'    => 'rewrite_rules',

		// options in rewrite_rules group
		'content' => array(
			'custom_rw_rules' => array(
				'name'    => 'custom_rw_rules',
				'default' => array(
					// fix paginated content rewrite rule (even with EP_ALL, paginated content
					// is not taken into account)
					//
					// use naming convention to order rules
					// naming: NN.jetpack.project-type
					// NN is an integer, standard rules have NN = 100
					// Higher number have higher precedence

					/**
					 * Priority 200
					 */
					// categories
					'200.categories'         => array(
						'rule'                => '{CATEGORY_BASE}/(.+?)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?category_name=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),
					'200.categories.numeric' => array(
						'rule'                => 'archives/{CATEGORY_BASE}/(.+?)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?category_name=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_NUMERIC,
						'position'            => 'top'
					),
					'200.categories.custom.category.postname'            => array(
						'rule'                => '{CATEGORY_BASE}/(.+?)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?category_name=$matches[1]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_CUSTOM_CATNAME_POSTNAME,
						'position'            => 'top'
					),
					'200.categories.custom.category.postname.page'            => array(
						'rule'                => '{CATEGORY_BASE}/(.+?)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?category_name=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_CUSTOM_CATNAME_POSTNAME,
						'position'            => 'top'
					),
					// tags
					'200.tags'               => array(
						'rule'                => '{TAG_BASE}/(.+?)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?tag=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),
					'200.tags.numeric'       => array(
						'rule'                => 'archives/{TAG_BASE}/(.+?)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?tag=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_NUMERIC,
						'position'            => 'top'
					),
					'200.tags.custom.category.postname'       => array(
						'rule'                => '{TAG_BASE}/(.+?)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?tag=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_CUSTOM_CATNAME_POSTNAME,
						'position'            => 'top'
					),
					'200.tags.custom.category.postname.page'       => array(
						'rule'                => '{TAG_BASE}/(.+?)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?tag=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_CUSTOM_CATNAME_POSTNAME,
						'position'            => 'top'
					),
					// Author
					'200.author'             => array(
						'rule'                => 'author/([^/]+)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?author_name=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),
					'200.author.numeric'     => array(
						'rule'                => 'archives/author/([^/]+)/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?author_name=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_NUMERIC,
						'position'            => 'top'
					),

					// archives
					'200.archives'           => array(
						'rule'                => '([0-9]{4})/([0-9]{1,2})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?year=$matches[1]&monthnum=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),

					'200.archives.page' => array(
						'rule'                => '([0-9]{4})/([0-9]{1,2})/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?year=$matches[1]&monthnum=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),

					'200.archives.numeric.page'     => array(
						'rule'                => 'archives/date/([0-9]{4})/([0-9]{1,2})/{PAGINATION_BASE}/([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?year=$matches[1]&monthnum=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_NUMERIC,
						'position'            => 'top'
					),

					/**
					 * Priority 150
					 */

					// Posts: Numeric
					// this one's special: in PERMALINK_NUMERIC mode, posts urls are archives/NN
					// This makes them undistinguishable from pages with page number (ie: sample-page/3)
					// unless we remove the rule 120.pages. But we actually need it, so to keep it
					// we insert this rule, 150.posts.numeric, which is the only one here meant
					// for regular pages (ie without pagination)
					'150.posts.numeric.page'        => array(
						'rule'                => 'archives/([0-9]+)/([0-9]+)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?p=$matches[1]&page=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_NUMERIC,
						'position'            => 'top'
					),
					// Posts+comment: Numeric
					'150.posts.comments.numeric'    => array(
						'rule'                => 'archives/([0-9]+)/comment-page-([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?p=$matches[1]&cpage=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_NUMERIC,
						'position'            => 'top'
					),

					// Posts: Day & name
					'150.posts.day.name'            => array(
						'rule'                => '([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)(?:/([0-9]+))?/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&page=$matches[5]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_DAY_NAME,
						'position'            => 'top'
					),
					// Posts: Month & name
					'150.posts.month.name'          => array(
						'rule'                => '([0-9]{4})/([0-9]{1,2})/([^/]+)(?:/([0-9]+))?/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?year=$matches[1]&monthnum=$matches[2]&name=$matches[3]&page=$matches[4]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_MONTH_NAME,
						'position'            => 'top'
					),

					// Posts+comment: Day & name
					'150.posts.comments.day.name'   => array(
						'rule'                => '([0-9]{4})/([0-9]{1,2})/([0-9]{1,2})/([^/]+)/comment-page-([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?year=$matches[1]&monthnum=$matches[2]&day=$matches[3]&name=$matches[4]&cpage=$matches[5]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_DAY_NAME,
						'position'            => 'top'
					),

					// Posts+comment: Month & name
					'150.posts.comments.month.name' => array(
						'rule'                => '([0-9]{4})/([0-9]{1,2})/([^/]+)/comment-page-([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?year=$matches[1]&monthnum=$matches[2]&name=$matches[3]&cpage=$matches[4]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_MONTH_NAME,
						'position'            => 'top'
					),

					// Posts+comment: custom /%category%/%post%/
					'150.posts.comments.custom.category.postname'   => array(
						'rule'                => '(.+?)/([^/]+)/comment-page-([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?category_name=$matches[1]&name=$matches[2]&cpage=$matches[3]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_CUSTOM_CATNAME_POSTNAME,
						'position'            => 'top'
					),

					// Search results
					'150.search.results'            => array(
						'rule'                => 'page/([0-9]+)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?&paged=$matches[1]&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),

					/**
					 * Priority 120
					 */

					// Pages
					'120.pages'                     => array(
						'rule'                => '(.?.+?)/([0-9]+)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?pagename=$matches[1]&page=$matches[2]' . '&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),

					// Posts page
					'120.archives.posts_page' => array(
						'rule'                => '(.?.+?)/{PAGINATION_BASE}/([0-9]+)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?pagename=$matches[1]&paged=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),

					// Pages+comments
					'120.pages.comments'            => array(
						'rule'                => '(.?.+?)/comment-page-([0-9]+)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?pagename=$matches[1]&cpage=$matches[2]' . '&{AMP_SUFFIX}=1',
						'permalink_structure' => '',
						'position'            => 'top'
					),

					/**
					 * Priority 110
					 */

					// Posts+comment: Post name
					'110.posts.comments.postname'   => array(
						'rule'                => '([^/]+)/comment-page-([0-9]{1,})/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?name=$matches[1]&cpage=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_POSTNAME,
						'position'            => 'top'
					),

					/**
					 * Priority 100
					 */
					// Posts: Post name
					'100.posts.postname'            => array(
						'rule'                => '([^/]+)/([0-9]+)/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?name=$matches[1]&page=$matches[2]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_POSTNAME,
						'position'            => 'top'
					),
					// Posts: Custom: /%category%/%postname%/
					'100.posts.custom.category.postname'            => array(
						'rule'                => '(.+?)/([^/]+)(?:/([0-9]+))?/{AMP_SUFFIX}/?$',
						'rewrite'             => 'index.php?category_name=$matches[1]&name=$matches[2]&page=$matches[3]&{AMP_SUFFIX}=1',
						'permalink_structure' => WeeblrampClass_Route::PERMALINK_CUSTOM_CATNAME_POSTNAME,
						'position'            => 'top'
					),
				)
			)
		)
	),

	// List of assets in the system ----------------------------------------------------
	array(
		'name'    => 'assets',

		// options in assets group
		'content' => array(
			'assets.settings_logo'     => array(
				'name'    => 'assets.settings_logo',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 34.808002 5.6791639"><g fill-rule="evenodd"><path d="M59.703303 73.021088l.01736-.003.48412-2.215667h.667499l-.847944 3.117572h-.570186l-.659186-2.129362-.0056-.02877-.0029.02877-.653318 2.129362h-.570243l-.847944-3.117572h.667499l.495612 2.183948.01736.003.644516-2.186899h.507348zM62.6892 73.98053c-.439376 0-.789507-.14458-1.050149-.433741-.260888-.28916-.391209-.6602-.391209-1.113612v-.11532c0-.453411.129344-.829369.388275-1.127873.258931-.29875.583144-.447264.972641-.445297.418348 0 .738895.127368.961394.381859.2225.25449.33375.596024.33375 1.024356v.411857h-1.934036l-.0056.01451c.01149.246868.08338.448985.216143.60586.132766.15712.316634.235557.551604.235557.187291 0 .347686-.02311.48143-.06909.133745-.04623.262599-.11237.386808-.198921l.223477.459067c-.116384.104255-.271156.192282-.464071.263588-.192914.07155-.416392.107206-.670433.107206zm-.08044-2.673997c-.171887 0-.313211.06885-.423972.206052-.110761.137449-.179467.311782-.206362.522997l.0059.01451h1.229127v-.07204c0-.197938-.05012-.359238-.15037-.484147-.100248-.12491-.251841-.187365-.454291-.187365zM65.795149 73.98053c-.439375 0-.789507-.14458-1.050149-.433741-.260887-.28916-.391209-.6602-.391209-1.113612v-.11532c0-.453411.129344-.829369.388275-1.127873.258931-.29875.583144-.447264.972641-.445297.418349 0 .738895.127368.961394.381859.2225.25449.33375.596024.33375 1.024356v.411857h-1.934036l-.0056.01451c.01149.246868.08338.448985.216142.60586.132766.15712.316634.235557.551604.235557.187291 0 .347686-.02311.481431-.06909.133744-.04623.262598-.11237.386807-.198921l.223477.459067c-.116384.104255-.271156.192282-.46407.263588-.192915.07155-.416393.107206-.670434.107206zm-.08044-2.673997c-.171887 0-.313211.06885-.423972.206052-.110761.137449-.179467.311782-.206362.522997l.0059.01451h1.229128v-.07204c0-.197938-.05012-.359238-.150371-.484147-.100247-.12491-.251841-.187365-.454291-.187365zM70.293555 72.464896c0 .455379-.105626.821747-.316634 1.099351-.211008.277604-.508571.416283-.892444.416283-.192914 0-.360645-.03934-.502947-.118025-.142302-.07893-.261131-.194249-.356733-.345959l-.06871.403496h-.584612v-4.495019h.696351v1.731767c.09536-.132532.21003-.234329.343775-.305389.133744-.07106.289249-.106714.467004-.106714.387785 0 .687304.151711.898312.455378.211008.303422.316634.704952.316634 1.204344zm-.69635-.06049c0-.324568-.0555-.586927-.166264-.786586-.110761-.199658-.286315-.299733-.527153-.299733-.154772 0-.284115.03467-.388274.103763-.104159.06909-.186558.165235-.247684.288177v1.308107c.05917.12491.141324.221296.246217.289652.105137.06811.236925.102289.395609.102289.240593 0 .415414-.08508.524219-.254983.108805-.170152.16333-.400055.16333-.690199zM71.637356 73.920042H70.94125v-4.495019h.696106zM73.961133 71.43341l-.297807-.01156c-.135701 0-.248907.02877-.339618.08655-.09071.05754-.160884.13917-.210519.244655v2.166982h-.696351v-3.117572h.636203l.04572.452182c.07824-.159334.178978-.284243.302209-.374483.12323-.09024.265288-.135482.425683-.135482.04206 0 .08118.0034.117363.01008.03643.0069.06968.015.100247.02459z" fill="#7e7e7e" transform="translate(-56.715 -68.3)"/><path d="M79.243667 73.496629c.03423.103763.05575.185889.06431.246376.0086.06049-.0029.105731-.03423.135974-.03154.03024-.08753.04893-.16773.05631-.0802.0071-.19047.01082-.330816.01082-.146214 0-.260153-.0022-.341818-.0066-.08167-.0042-.144014-.01303-.187047-.02582-.04303-.01303-.07311-.03098-.09022-.05409-.01712-.02311-.03154-.05336-.04279-.09073l-.374093-1.123693h-2.088808l-.352332 1.093449c-.01149.04033-.02665.07426-.04523.101551-.01858.02729-.04866.04893-.09022.06491-.04157.01574-.100247.02656-.176288.03246-.0758.0057-.17531.0086-.298541.0086-.131788 0-.234969-.0044-.309543-.01303-.07433-.0086-.12592-.02951-.154772-.0627-.02861-.03319-.03863-.07991-.03007-.1404.0088-.06049.03007-.141138.06455-.242197l1.714959-4.961708c.01712-.04893.03717-.08852.06015-.119009.02274-.03024.05941-.05336.109538-.06909.05012-.01574.119563-.02582.208563-.03024.08875-.0044.206118-.0064.352332-.0064.168953 0 .303675.002.403922.0064.100248.0044.178489.01451.234236.03024.05599.01574.09609.03959.120297.07131.02445.03172.04523.075.06235.129582zm-2.553123-4.10185h-.0042l-.786574 2.377214h1.577303zM86.503025 73.764397c-.00024.02902-.008.05483-.0237.07795-.0156.02311-.0445.0418-.0861.05606-.0416.01451-.0966.02606-.16529.03467-.069.0086-.15624.01303-.26235.01303-.10318 0-.189-.0044-.25771-.01303-.069-.0086-.12323-.02016-.16333-.03467-.0401-.01426-.0687-.03295-.0861-.05606-.0171-.02311-.0257-.04893-.0257-.07795v-4.55108h-.009l-1.611534 4.5469c-.01149.03737-.03008.06836-.05599.09295-.02567.02434-.06088.04401-.105383.05827-.04425.01451-.100978.02385-.169685.02803-.06871.0044-.151839.0066-.24915.0066-.09756 0-.180446-.0037-.249396-.01082-.06871-.0074-.125187-.01893-.169687-.03467-.0445-.01574-.07946-.03516-.105382-.05827-.02567-.02311-.04303-.05041-.05159-.08213l-1.555787-4.5469h-.0086v4.55108c0 .02902-.0078.05483-.02372.07795-.01565.02311-.04499.0418-.08802.05606-.04303.01451-.09829.02606-.16553.03467-.06748.0086-.154039.01303-.260154.01303-.103181 0-.189002-.0044-.257708-.01303-.06895-.0086-.123964-.02016-.16553-.03467-.04157-.01426-.07017-.03295-.08607-.05606-.01565-.02311-.02347-.04893-.02347-.07795v-4.983306c0-.147039.03863-.259408.115896-.337108.07751-.07794.180689-.116795.309544-.116795h.739139c.131788 0 .244994.01082.339617.03246.09462.02164.176289.05754.244994.107943.06871.05065.126165.116795.171888.198921.04597.08213.08607.183676.120296.304651l1.203454 3.332476h.01736l1.246238-3.32387c.0372-.120975.078-.223263.1225-.306864.0445-.0836.0961-.151219.15477-.203101.0587-.05188.12836-.08852.20856-.110156.0802-.02164.17311-.03246.27923-.03246h.76065c.0775 0 .14401.01008.20001.03024.0557.02016.10171.04967.13741.08876.0359.03885.0631.08631.0817.142613.0186.05606.0279.120238.0281.192282zM91.522965 70.02572c0 .313995-.0487.59209-.14622.834287-.0973.24195-.23912.445789-.42544.611515-.18606.165726-.41468.291865-.68559.378171-.27067.08655-.5895.129827-.95626.129827h-.46407v1.784877c0 .02902-.009.05483-.0279.07795-.0188.02311-.0496.0418-.0924.05606-.043.01451-.10024.02606-.17188.03467-.0716.0086-.16333.01303-.27507.01303-.10905 0-.20001-.0044-.27312-.01303-.0731-.0086-.13105-.02016-.17408-.03467-.0428-.01426-.0729-.03295-.0902-.05606-.0171-.02311-.0257-.04893-.0257-.07795v-5.031048c0-.135482.035-.237032.10514-.304651.0702-.06762.1626-.10155.27727-.10155h1.31104c.13178 0 .25697.0052.37604.01524.11883.01008.26138.03172.42764.06467.16602.0332.33449.09442.50491.183676.17042.0895.3159.202609.43619.339321.1203.136958.21199.296783.27507.479721.0631.182939.0946.388252.0946.615942zm-1.18194.08213c0-.19597-.0345-.35727-.10318-.483901-.0687-.126876-.15331-.220559-.25355-.281046-.10025-.06049-.20563-.09885-.31591-.114583-.11027-.01574-.22421-.0236-.34157-.0236h-.48143v1.897246h.5071c.18045 0 .3318-.02434.45356-.07352.12177-.04893.22128-.117287.29854-.205068.0775-.08803.13619-.193266.17629-.315716.0401-.122451.0601-.25572.0601-.399809z" fill="#327dcb" transform="translate(-56.715 -68.3)"/></g></svg>',
			),
			'assets.amp_logo'          => array(
				'name'    => 'assets.amp_logo',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16.027927 15.875"><path d="m 77.906108,70.317597 -3.361796,5.541169 h -0.60907 l 0.602191,-3.610769 -1.864783,0.0026 h -0.02646 c -0.167482,0 -0.303742,-0.134937 -0.303742,-0.300831 0,-0.07144 0.0672,-0.192352 0.0672,-0.192352 l 3.350683,-5.535083 0.619125,0.0026 -0.617008,3.616325 1.874308,-0.0021 0.02963,-5.29e-4 c 0.16801,0 0.304271,0.134937 0.304271,0.301625 0,0.0672 -0.02646,0.12647 -0.06482,0.176741 z m -2.749813,-7.214526 c -4.425951,0 -8.013701,3.553884 -8.013701,7.9375 0,4.384146 3.58775,7.9375 8.013701,7.9375 4.426477,0 8.014227,-3.553618 8.014227,-7.9375 0,-4.383616 -3.58775,-7.9375 -8.014227,-7.9375 z" transform="translate(-67.143 -63.103)"/></svg>'
			),
			'assets.community_logo'    => array(
				'name'    => 'assets.community_logo',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M408.2 611.2c-145.1 0-263.1-118-263.1-263.2 0-145.1 118-263.1 263.1-263.1 145.1 0 263.2 118 263.2 263.1C671.4 493.2 553.3 611.2 408.2 611.2zM408.2 143.2c-113 0-204.9 91.9-204.9 204.8 0 113 91.9 204.9 204.9 204.9 113 0 204.9-91.9 204.9-204.9C613.1 235.1 521.2 143.2 408.2 143.2zM408.2 699.6c145.1 0 273.5 85.1 353.5 215.5 15.5-11.9 30.5-24.5 44.7-37.9-90.7-142.8-235.2-235.9-398.2-235.9-163 0-307.5 93.1-398.2 235.9 14.3 13.4 29.2 26 44.7 37.9C134.7 784.7 263.2 699.6 408.2 699.6z"/><path d="M736.3 552.8c92.5 0 167.7-75.2 167.7-167.7 0-92.4-75.2-167.6-167.7-167.6-53.9 0-101.4 26-132.1 65.7l14.4 46.5c20.9-44.2 65.6-75.1 117.7-75.1 72 0 130.5 58.5 130.5 130.5 0 72-58.5 130.5-130.5 130.5-51.5 0-95.6-30.2-116.9-73.6-5.2 14.5-10.3 30.6-14.1 46.4C636 527.4 683 552.8 736.3 552.8zM736.3 572c-90.2 0-171.5 44.8-229.2 116.3l37.2 13.8c50.1-57.2 117.5-92.9 192-92.9 92.4 0 174.3 54.2 225.2 137.3 9.9-7.6 19.4-15.6 28.5-24.1C932.2 631.3 840.1 572 736.3 572z"/></svg>'
			),
			'assets.icons.upgrade'     => array(
				'name'    => 'assets.icons.upgrade',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M596.8,492.2C592.4,487.6,609.8,507,596.8,492.2L596.8,492.2z"/><path d="M534.1,288.6c-4-5.6-9.5-10.3-16.2-13.3c-6.1-2.8-12.8-4.1-19.4-3.8c-0.7,0-1.3,0.1-2,0.1c0,0,0,0,0,0c-1.7,0.1-3.4,0.4-5,0.8c-8.2,1.7-15.9,5.9-21.6,12.4c-0.3,0.3-75.6,85.3-146.8,165.7c-1.7,1.9-3.4,3.9-4.9,6c-13.3,18-8.7,45.3,9.8,57.6c18.9,12.6,40.4,9.8,56.1-7.8c24.9-27.9,49.7-55.9,74.5-83.9c0,87.2,0,174.4,0,261.6c0,2.6,0,5.2,0.3,7.7c2,22.3,23.5,39.6,45.5,36.6c22.5-3.1,36.7-19.5,36.8-43c0.1-54.1,0-108.2,0-162.4c0-25.1,0-50.3,0-75.4c0-8.4,0-16.8,0.1-25.3c12.1,13.8,24.2,27.7,36.3,41.5c16.6,18.9,16.1,18.4,32.7,37.3c0.8,0.9,1.4,1.6,2,2.3c1,1,2.9,3.1,6.5,6.9c20.3,21.9,57.2,14,67.6-14c6.3-16.7,2.1-31.4-9.5-44.6C606.3,371,604.4,368.8,534.1,288.6L534.1,288.6L534.1,288.6z"/><path d="M500,10C231,10,10.6,230.1,10,499.7C9.4,768.5,230.7,990,500,990c269.1,0,489.4-220.1,490-489.7C990.6,231.5,769.3,10,500,10z M500.3,916.7c-228.1,0.8-416.2-187-417-416.4c-0.8-228.1,187-416.2,416.4-417c228.1-0.8,416.2,187,417,416.4C917.5,727.9,729.7,915.9,500.3,916.7z"/></svg>'
			),
			'assets.icons.home'        => array(
				'name'    => 'assets.icons.home',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M982.2,489.9l-450-449.3c-5.6-5.6-12.7-14.6-19.8-18.9c-2.9-3.8-7.3-6.4-12.4-6.4c-5,0-9.3,2.5-12.2,6.1c-7.7,4.1-15.8,13.4-21.5,19.2L17.8,489.1c-10.3,10.3-10.3,27.1,0,37.4c0.4,0.4,0.9,0.5,1.3,0.9c4.8,4.9,11.4,7.9,18.8,7.9h105.7v370c0,43.8,35.5,79.3,79.3,79.3h555c43.8,0,79.3-35.5,79.3-79.3v-370h105.7c3.7,0,7.2-0.8,10.4-2.1c3.3-1.3,6.3-3.2,8.9-5.9C992.6,517,992.6,500.2,982.2,489.9L982.2,489.9z M830.8,482.4c-14.6,0-26.4,11.8-26.4,26.4v26.4V570v308.9c0,29.2-23.7,52.9-52.9,52.9H537.4c1.5-4.2,2.7-8.5,2.7-13.2V680.7c0-21.9-17.7-39.6-39.6-39.6c-21.9,0-39.6,17.8-39.6,39.6v237.9c0,4.7,1.2,9,2.7,13.2H249.3c-29.2,0-52.9-23.7-52.9-52.9V535.3c0.1,0,0.1,0,0.2,0v-25c0-0.5-0.2-0.9-0.2-1.4c0-14.6-11.8-26.4-26.4-26.4H99.2l400-400l400.6,400H830.8L830.8,482.4z"/></svg>'
			),
			'assets.icons.select_list' => array(
				'name'    => 'assets.icons.select_list',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M464.4,207.2h485.2c22.3,0,40.4-18.1,40.4-40.4s-18.1-40.4-40.4-40.4H464.4c-22.3,0-40.4,18.1-40.4,40.4S442,207.2,464.4,207.2z M949.6,490.2H464.4c-22.3,0-40.4,18.1-40.4,40.4c0,22.3,18.1,40.4,40.4,40.4h485.2c22.3,0,40.4-18.1,40.4-40.4C990,508.3,971.9,490.2,949.6,490.2z M949.6,854.1H464.4c-22.3,0-40.4,18.1-40.4,40.4c0,22.3,18.1,40.4,40.4,40.4h485.2c22.3,0,40.4-18.1,40.4-40.4C990,872.2,971.9,854.1,949.6,854.1z M291.2,34L145.9,179.4L61.8,95.3c-11.8-11.8-31-11.8-42.9,0c-11.8,11.8-11.8,31,0,42.9l100.1,100.1c7.4,7.4,17.5,10.1,27,8.4c9.5,1.8,19.8-1,27.2-8.4L334.3,77.1c11.9-11.9,11.9-31.2,0-43.1C322.4,22.1,303.1,22.1,291.2,34z M291.2,397.9L145.9,543.3l-84.1-84.1c-11.8-11.8-31-11.8-42.9,0C7,471,7,490.2,18.9,502.1l100.1,100.1c7.4,7.4,17.5,10.1,27,8.4c9.5,1.8,19.8-1,27.2-8.4L334.3,441c11.9-11.9,11.9-31.2,0-43.1C322.4,386,303.1,386,291.2,397.9z M291.2,761.8L145.9,907.2l-84.1-84.1c-11.8-11.8-31-11.8-42.9,0C7,834.9,7,854.1,18.9,866L118.9,966c7.4,7.4,17.5,10.1,27.1,8.4c9.5,1.8,19.8-1,27.2-8.4l161.1-161.1c11.9-11.9,11.9-31.2,0-43.1C322.4,749.9,303.1,749.9,291.2,761.8z"/></svg>'
			),
			'assets.icons.website'     => array(
				'name'    => 'assets.icons.website',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M500,990C229.4,990,10,770.6,10,500C10,229.4,229.4,10,500,10c270.6,0,490,219.4,490,490C990,770.6,770.6,990,500,990z M909.8,654.7H787.6c-38.6,123.4-126,224.6-239.5,280.5C714.5,917,852.6,806,909.8,654.7z M757.9,512.9c0-39.2-5.3-78.2-14.7-116.1H525.8v206.3h222.7C754.5,574,757.9,543.9,757.9,512.9z M474.2,654.7H270.6c37.7,99.5,111.2,192.9,204.2,242.6L474.2,654.7z M474.2,603.2V396.8H253.8c-7.6,33.8-11.7,68.4-11.7,103.2c0,35.6,4.3,70.1,12.3,103.2H474.2z M474.2,345.3V95.8c-94.6,53.6-168.3,141.3-205.5,249.4H474.2z M727.5,345.3C689.2,240.4,617.2,149.4,525.8,97v248.3H727.5z M525.8,654.7v249.2c97.6-52.8,173.1-141.7,209-249.2H525.8z M474.2,937.4v-9.5V937.4c-119.5-50.5-213.5-159.7-257.1-282.7H90.2C149.9,812.7,297.9,927.1,474.2,937.4z M74.7,395.2c-8.6,34.2-13.2,67.9-13.2,104.8c0,35.6,4.7,70,12.7,103.2h128.1c-7.6-33.2-11.9-67.6-11.9-103.2c0-34.8,4.2-69.3,11.5-103.2H87.4C82.9,396.8,78.4,397.3,74.7,395.2z M90.2,345.3h125.4c38.5-117.7,130.9-222.8,234.2-281.7C289.8,86.4,145.7,198.3,90.2,345.3z M545.4,64.5c108.2,55.9,193,160,235,280.8h129.4C852.3,193.2,713,81.8,545.4,64.5z M795.7,396.8c9,37.9,13.8,76.8,13.8,116.1c0,30.9-3.3,61-8.9,90.3h125.1c8-33.1,12.7-67.5,12.7-103.2c0-35.6-4.7-70-12.7-103.2H795.7z"/></svg>'
			),
			'assets.icons.publisher'   => array(
				'name'    => 'assets.icons.publisher',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M664.8,476.3c57.3-47.5,94-119.2,94-199.3c0-142.6-116.1-258.7-258.7-258.7c-142.7,0-258.7,116.1-258.7,258.7c0,80.1,36.6,151.8,94,199.3C145.9,544.1,10,725.3,10,937.7v44h980v-44C990,725.3,854.1,544.1,664.8,476.3z M329.3,277c0-94.1,76.6-170.7,170.7-170.7c94.1,0,170.7,76.6,170.7,170.7c0,94.1-76.6,170.7-170.7,170.7C405.9,447.7,329.3,371.1,329.3,277z M100.4,893.7c22-201.1,192.8-358,399.6-358c206.8,0,377.7,157,399.6,358H100.4z"/></svg>'
			),
			'assets.icons.umbrella'    => array(
				'name'    => 'assets.icons.umbrella',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M642.6,551c-13.6,0-24.7-11-24.7-24.7c0-8.9-12-20.4-30.6-29.4c-25.1-12-60.4-18.9-96.9-18.9c-36.5,0-71.8,6.9-96.9,18.9c-18.6,8.9-30.6,20.4-30.6,29.4c0,13.6-11,24.7-24.7,24.7c-13.6,0-24.7-11-24.7-24.7c0-8.9-12-20.4-30.6-29.4C258,485,222.7,478,186.2,478c-39.4,0-76.6,7.9-102,21.6c-8.1,4.3-17.9,3.9-25.5-1.2c-7.6-5.1-11.7-14-10.8-23.1C60.1,362.9,112.4,259.1,195.2,183c83.5-76.7,191.6-119,304.2-119c115,0,224.7,43.8,308.9,123.4c83.6,79,134.7,186.1,143.8,301.4c0.8,9.9-4.5,19.4-13.4,23.9c-8.9,4.5-19.6,3.2-27.2-3.2c-22.3-19.1-68.1-31.4-116.8-31.4c-36.5,0-71.8,6.9-96.9,18.9c-18.6,8.9-30.6,20.4-30.6,29.4C667.2,540,656.2,551,642.6,551z M186.2,428.7c44.3,0,86.2,8.4,118.2,23.8c13.5,6.5,24.9,14,33.9,22.4c9-8.4,20.4-15.9,33.9-22.4c32-15.3,74-23.8,118.2-23.8c44.3,0,86.2,8.4,118.2,23.8c13.5,6.5,24.9,14,33.9,22.4c9-8.4,20.4-15.9,33.9-22.4c32-15.3,74-23.8,118.2-23.8c37.5,0,72.8,6,101.8,16.8c-37.2-189.7-203.4-332.2-397.1-332.2c-193,0-356.6,137.5-395.9,326C128.4,432.4,156.7,428.7,186.2,428.7z"/><path d="M466 431.4h49.3v507.2H466V431.4L466 431.4zM490.6 94.4c-13.6 0-24.7-11-24.7-24.7V34.7C466 21 477 10 490.6 10s24.7 11 24.7 24.7v35.1C515.3 83.4 504.2 94.4 490.6 94.4z"/><path d="M332.6,498.3c-13.6,0-24.7-11-24.7-24.7c0-84,15.9-165.8,45.9-236.5c29.7-70,72-126.4,122.3-163c11-8,26.4-5.6,34.4,5.4c8,11,5.6,26.4-5.4,34.4c-89.9,65.5-147.9,206.7-147.9,359.7C357.2,487.3,346.2,498.3,332.6,498.3z"/><path d="M648.7 498.3c-13.6 0-24.7-11-24.7-24.7 0-153-58.1-294.2-147.9-359.7-11-8-13.4-23.4-5.4-34.4 8-11 23.4-13.4 34.4-5.4 50.3 36.6 92.5 93 122.3 163 30 70.7 45.9 152.5 45.9 236.5C673.3 487.3 662.3 498.3 648.7 498.3zM543.3 990c-43.4 0-77.3-26.3-77.3-59.8 0-13.6 11-24.7 24.7-24.7 13.6 0 24.6 11 24.7 24.6.8 2.6 10.5 10.6 28 10.6 17.5 0 27.2-7.9 28-10.6.1-13.6 11.1-24.6 24.7-24.6 13.6 0 24.7 11 24.7 24.7C620.6 963.7 586.7 990 543.3 990z"/></svg>'
			),
			'assets.icons.gear'        => array(
				'name'    => 'assets.icons.gear',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M4261.6,5003c-3.8-13.4-38.4-343.3-76.7-734.5c-94-976.2-69-863-197.5-891.8c-145.8-32.6-341.4-103.6-544.7-195.6l-166.8-78.6l-178.4,145.7c-97.8,80.6-372.1,304.9-609.9,498.6l-431.5,352.9l-517.8-506.3c-283.8-280-519.7-514-523.6-519.7c-1.9-7.7,147.7-199.5,333.7-425.8c186-226.3,402.7-491,481.4-588.8l141.9-174.5l-76.7-138.1c-97.8-172.6-191.8-385.5-258.9-588.8c-44.1-132.3-59.5-159.2-94-161.1c-23,0-356.7-32.6-742.2-71l-700-71V116.4v-738.3l700-69.1c385.5-38.4,719.2-72.9,744.1-76.7c38.4-5.7,53.7-36.4,105.5-189.8c32.6-99.7,117-299.2,187.9-441.1l130.4-258.9L1826-1830.1c-76.7-94-291.5-358.6-477.5-584.9c-184.1-226.3-333.7-412.3-331.8-414.2c1.9-3.8,235.9-237.8,519.7-523.6l515.9-519.7l88.2,74.8c47.9,40.3,308.8,251.2,577.3,471.8c268.5,218.6,504.4,412.3,521.7,427.7c30.7,26.9,49.9,21.1,201.4-47.9c205.2-95.9,400.8-164.9,548.5-197.5c59.5-13.4,109.3-34.5,111.2-46c0-11.5,36.4-374,80.5-807.4l80.6-786.3H5000h738.4l80.5,786.3c44.1,433.4,80.5,795.9,80.5,807.4c1.9,11.5,51.8,32.6,113.1,46c145.8,32.6,341.4,101.6,546.6,197.5c151.5,69.1,170.7,74.8,201.4,47.9c17.3-15.3,253.2-209,521.6-427.7c268.5-220.5,529.3-431.5,577.3-471.8l86.3-72.9l521.7,521.7l521.7,521.7L8651.5-2415c-186,226.3-400.8,490.9-477.5,584.9L8032-1657.5l130.4,258.9c70.9,141.9,155.3,341.4,187.9,441.1c51.8,153.4,67.1,184.1,105.5,189.8c24.9,3.8,358.6,38.4,744.1,76.7l700,69.1v738.3v738.4l-700,71c-385.5,38.4-719.2,71-742.2,71c-34.5,1.9-49.9,26.8-94,161.1c-61.4,187.9-163,416.2-262.7,594.5l-72.9,130.4l72.9,90.1c40.3,49.9,249.3,306.9,464.1,569.6c214.8,264.7,398.9,489,406.6,500.5c11.5,13.4-166.8,205.2-502.5,540.8l-519.7,521.6l-521.6-425.8c-285.7-234-560-460.3-609.9-500.5l-92.1-76.7l-166.8,76.7c-205.2,95.9-400.8,164.9-546.6,197.5c-61.4,13.4-111.2,34.5-113.1,46c0,11.5-36.4,375.9-80.5,807.4l-80.5,786.3l-734.5,5.8C4426.6,5026,4269.3,5022.2,4261.6,5003z M5561.9,2258.6C6390.4,2040,7031,1343.8,7176.7,503.8c36.4-207.1,36.4-567.7,0-772.9c-138.1-790.1-703.8-1449.9-1467.1-1708.8c-439.2-149.6-972.3-149.6-1409.6-3.8c-701.9,234-1248.5,817-1444.1,1536.2c-46,172.6-49.9,216.7-49.9,561.9c0,345.2,3.8,389.3,49.9,561.9c220.5,811.2,870.7,1426.9,1693.4,1605.2C4808.2,2339.2,5299.2,2327.7,5561.9,2258.6z" transform="matrix(.1 0 0 -.1 0 512)"/></svg>'
			),
			'assets.icons.seo'         => array(
				'name'    => 'assets.icons.seo',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M3461.7,5004.5c-628.2-68.7-1278.5-309.2-1781.6-660.1c-265-184.1-733.8-652.8-917.8-917.8c-292-419.6-517.8-964.4-618.4-1487.1C85,1620.4,85,965.2,146.3,638.8C291.1-144,622.4-772.3,1189.3-1339.1c554.6-554.6,1128.8-863.8,1916.6-1030.7c213.5-46.6,333.8-56.5,711.7-56.5c500.6,0,760.7,41.7,1187.8,184.1c1001.3,333.8,1840.5,1116.6,2250.3,2095.7C7736.6,1004.4,7609,2310,6907.2,3375c-203.7,309.2-687.1,795.1-1001.3,1003.7c-417.2,277.3-885.9,471.2-1374.2,569.3C4301,4994.7,3677.6,5026.6,3461.7,5004.5z M4553.7,4545.6c441.7-105.5,881-301.9,1214.8-547.3l162-117.8l-269.9-269.9L5393,3343.1l-85.9,73.6c-130.1,115.3-284.7,142.3-790.2,142.3c-709.2,0-530.1,115.3-1774.2-1126.4c-696.9-694.5-1077.3-1092-1109.2-1158.3c-61.4-125.2-61.4-262.6,0-387.7c29.5-66.3,326.4-377.9,827-878.5c689.6-684.7,792.6-780.4,888.4-804.9c115.3-29.5,242.9-17.2,346,36.8c34.4,19.6,542.3,517.8,1133.8,1109.2l1070,1074.9l34.4,147.2c19.6,93.3,31.9,301.8,31.9,564.4c-2.5,505.5-34.4,645.4-189,812.3l-103.1,110.4l277.3,274.8l274.8,274.9l76.1-85.9c395.1-454,655.2-964.4,782.8-1548.5c83.5-370.6,83.5-1003.7,2.5-1369.3C6789.4-713.4,5820-1685.2,4502.2-1979.6c-368.1-81-1001.2-81-1369.3,0c-652.8,147.2-1214.7,451.6-1673.6,910.5C1000.3-610.3,696-50.8,548.8,604.4c-81,365.6-81,998.8,2.5,1369.3C840.8,3284.2,1837.1,4283,3120.6,4550.5c338.6,71.2,368.1,73.6,795.1,63.8C4212.6,4606.9,4352.5,4592.2,4553.7,4545.6z M5282.6,2879.3l301.8-301.8v-466.3v-463.8l-1011.1-1016C4016.3,74.4,3540.2-394.3,3513.2-409.1c-39.3-22.1-142.4,71.2-790.2,719c-409.8,409.8-746,755.8-746,770.6c0,12.3,466.3,490.8,1035.6,1060.1l1038,1038h466.3h466.3L5282.6,2879.3z" transform="matrix(.1 0 0 -.1 0 511)"/><path d="M4482.6 2825.3c-198.8-71.2-370.6-301.8-370.6-495.7 0-191.4 164.4-431.9 363.2-535 206.1-105.5 397.6-66.3 584.1 117.8 206.1 206.1 225.8 424.6 58.9 665C4961.1 2808.1 4705.9 2906.3 4482.6 2825.3zM4750 2609.4c314.1-159.5 363.2-530.1 85.9-647.9-117.8-49.1-245.4-4.9-385.3 135-142.3 142.3-174.2 262.6-103 395.1 44.2 83.4 176.7 171.8 255.2 171.8C4624.9 2663.4 4691.2 2638.8 4750 2609.4zM3530.4 1919.8c-139.9-139.9-252.8-267.5-252.8-287.1 0-56.4 667.5-711.7 723.9-711.7 31.9 0 144.8 95.7 304.3 255.2 262.6 262.6 299.4 336.2 176.7 353.4-46.6 7.4-103.1-34.4-257.7-189l-201.2-198.8-108 110.4-108 110.4 179.1 181.6c181.6 181.6 213.5 262.6 115.3 279.8-29.5 7.4-105.5-49.1-225.8-169.3l-181.6-181.6-90.8 93.2-93.2 90.8 191.4 191.4c189 189 230.7 277.3 149.7 309.2-22.1 7.4-44.2 14.7-54 14.7C3790.5 2172.6 3670.3 2059.7 3530.4 1919.8zM2867.8 1267c-255.2-184-296.9-493.3-81-603.7 110.4-56.4 166.9-46.6 409.8 76.1 220.9 110.4 230.7 112.9 289.6 73.6 81-54 81-159.5 0-257.7-83.4-95.7-139.9-112.9-272.4-76.1-85.9 24.5-115.3 24.5-144.8 0-100.6-83.4 12.3-201.2 191.4-201.2 137.4 0 228.2 46.6 343.6 174.2 169.3 186.5 174.3 395.1 14.7 530.1-112.9 93.3-235.6 83.4-456.5-39.3-188.9-103.1-289.6-115.3-333.7-44.2-31.9 49.1 22.1 162 110.4 225.8 56.4 41.7 78.5 44.2 162 24.5 110.4-29.4 176.7-4.9 176.7 63.8C3277.6 1352.9 3029.8 1384.8 2867.8 1267zM7078.9-885.1c-245.4-363.2-723.9-841.7-1087.1-1087.1l-267.5-181.6 1224.6-1219.7c1101.9-1099.4 1241.7-1227 1386.5-1298.2 326.4-159.5 652.8-159.5 971.8-2.4 407.3 201.2 655.2 677.3 579.1 1119-63.8 365.7-63.8 365.7-1406.2 1712.9L7260.5-617.7 7078.9-885.1zM9442.1-3422.6c127.6-260.1 73.6-562-137.4-775.4-213.5-211.1-515.3-265.1-775.4-137.4-78.5 36.8-412.3 353.4-1146 1089.6l-1038 1038 198.8 157.1c216 174.2 488.4 451.5 660.1 672.4l110.4 139.9 1038-1035.6C9088.8-3010.3 9405.4-3344.1 9442.1-3422.6z" transform="matrix(.1 0 0 -.1 0 511)"/></svg>'
			),
			'assets.icons.tags'        => array(
				'name'    => 'assets.icons.tags',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M969.8,538L554.6,113.6c-6.2-6.3-14.6-9.9-23.5-9.9H334.4h-92H45.5c-19.6,0-35.5,15.9-35.5,35.5v298.4c0,8.8,3.4,17.1,9.6,23.3l414.6,414.6c27.7,27.7,72.6,27.7,100.4,0l48.2-48.2l48.2,48.2c27.7,27.7,72.6,27.7,100.4,0l237.8-237.8C996.7,610.3,996.9,565.7,969.8,538z M582.9,727l-50.2,50.2l-23.1,23.1c-13.9,13.9-36.4,13.9-50.2,0L81,421.8V174.7h125.9h71h40.6l379.5,387.8c13.6,13.9,13.5,36.2-0.2,49.9L582.9,727z M894.3,612.4l-188,187.9c-13.9,13.9-36.4,13.9-50.2,0l-23-23.1l139.4-139.4c27.5-27.5,27.7-72,0.6-99.8L417.6,174.7h97.5l379.5,387.8C908.1,576.3,908,598.6,894.3,612.4z"/><path d="M243.5,442.5c-58.3,0-105.7-47.5-105.7-105.7c0-58.2,47.5-105.7,105.7-105.7c58.2,0,105.7,47.5,105.7,105.7C349.2,395,301.9,442.5,243.5,442.5z M243.5,302.1c-19.2,0-34.7,15.5-34.7,34.7c0,19.2,15.5,34.7,34.7,34.7c19.2,0,34.7-15.5,34.7-34.7C278.2,317.6,262.7,302.1,243.5,302.1z"/></svg>'
			),
			'assets.icons.stats'       => array(
				'name'    => 'assets.icons.stats',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M100,110v-4900h4900h4900v288.2v288.2H5288.2H676.5V398.2V5010H388.2H100V110z" transform="matrix(.1 0 0 -.1 0 511)"/><path d="M7580.7,2592.7c-25-3.8-44.2-17.3-44.2-28.8c0-13.5,121.1-144.1,269-292.1l269-269L7004.2,932.4L5932-139.8l-722.5,722.5c-609.1,609.1-732.1,724.4-793.6,737.9c-159.5,36.5-128.8,63.4-1352.8-1158.7C2163.8-737.4,1919.7-991.1,1902.4-1046.8c-38.4-130.7,19.2-270.9,138.4-332.4c65.3-34.6,196-38.4,255.6-7.7c23.1,11.5,493.8,472.7,1045.3,1022.3l1005,1003.1l714.8-714.8c603.4-601.4,730.2-716.7,795.5-736c163.3-48,124.9-80.7,1423.9,1216.3L8478,1597.3l276.7-274.8c153.7-151.8,286.3-269,297.8-261.3c32.6,19.2,28.8,1506.5-1.9,1518C9021.8,2588.8,7644.1,2602.3,7580.7,2592.7z" transform="matrix(.1 0 0 -.1 0 511)"/></svg>'
			),
			'assets.icons.advert'      => array(
				'name'    => 'assets.icons.advert',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M903.7,570.1V831c0,18.2-10.3,33-33,33c-5.5,0-19.1-11.7-35.8-29.3V134.4c16.7-17.6,30.3-29.3,35.8-29.3c24.7,0,33,14.8,33,33v267.5c44.7,1.3,86.3,37.5,86.3,82.2C990,532.6,948.4,568.8,903.7,570.1L903.7,570.1z M373,633.7c2,0,0-298.3,0-298.3c226.6,0,360.9-99.5,431.7-167.7v633.7C733.9,733.2,599.6,633.7,373,633.7z M241,894.9L175,633h-66c0,0-19.6-44.5-28.5-99c-16.8,0-31.5,0-37.5,0c-18.2,0-33-14.8-33-33v-33c0-18.2,14.8-33,33-33c5.9,0,20.7,0,37.5,0c9-54.5,28.5-99,28.5-99h231v297h-66l8.3,33h32.9l16.5,66h-32.8L340,894.9H241L241,894.9z"/></svg>'
			),
			'assets.icons.display'     => array(
				'name'    => 'assets.icons.display',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M10,91.7V128h72.6v653.3h399.3V872H191.5v36.3h617V872H518.1v-90.7h399.3V128H990V91.7H10z M881.1,745H118.9V128h762.2V745z M445.6,236.8H227.8v217.8h217.8V236.8z M409.3,418.3H264.1V273.1h145.2L409.3,418.3L409.3,418.3z M772.2,418.3H518.1v36.3h254.1V418.3z M772.2,236.8H518.1v36.3h254.1V236.8z M772.2,327.6H518.1v36.3h254.1V327.6z M772.2,527.2H227.8v36.3h544.4V527.2z M772.2,636.1H227.8v36.3h544.4V636.1z"/></svg>'
			),
			'assets.icons.comments'    => array(
				'name'    => 'assets.icons.comments',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M836.9,816.3V990L665.2,884.3c-23.8,3.9-48.2,6.2-73.3,6.2c-117.9,0-223.6-45.1-296.5-116.4c12,0.7,23.9,1.6,36.1,1.6c17.1,0,34-0.8,50.7-2.2c57.6,39.6,130.3,63.4,209.7,63.4c27.3,0,53.8-3.1,79.3-8.4l59.6,39.8c-0.1,0-0.1,0.1-0.2,0.1l45,29.8V789.6c92.1-51.9,153.1-141.6,153.1-243.7c0-64.6-24.6-124-65.9-172.3c2.7-18.8,4.6-37.9,4.6-57.4c0-8.9-1-17.6-1.6-26.4C942.2,353.3,990,442.7,990,542.1C990,653.6,929.9,752.5,836.9,816.3L836.9,816.3z M408.1,706.7c-25.1,0-49.5-2.3-73.3-6.2L163.1,806.2V632.6C70.1,568.8,10,469.8,10,358.4C10,166,188.2,10,408.1,10C628,10,806.3,166,806.3,358.4C806.3,550.8,628,706.7,408.1,706.7L408.1,706.7z M408.1,71.3c-186.1,0-336.9,130.3-336.9,290.9c0,102.1,61,191.7,153.1,243.7v108.5l45-29.8c-0.1,0-0.1-0.1-0.2-0.1l59.7-39.8c25.5,5.3,51.9,8.4,79.2,8.4c186.1,0,336.9-130.2,336.9-290.9C745,201.5,594.2,71.3,408.1,71.3L408.1,71.3z M607.2,408.1c-25.4,0-45.9-20.6-45.9-45.9c0-25.4,20.6-45.9,45.9-45.9c25.4,0,45.9,20.6,45.9,45.9C653.1,387.6,632.6,408.1,607.2,408.1L607.2,408.1z M423.4,408.1c-25.4,0-45.9-20.6-45.9-45.9c0-25.4,20.6-45.9,45.9-45.9c25.4,0,45.9,20.6,45.9,45.9C469.4,387.6,448.8,408.1,423.4,408.1L423.4,408.1z M239.7,408.1c-25.4,0-45.9-20.6-45.9-45.9c0-25.4,20.6-45.9,45.9-45.9c25.4,0,45.9,20.6,45.9,45.9C285.6,387.6,265.1,408.1,239.7,408.1L239.7,408.1z"/></svg>'
			),
			'assets.icons.plug'        => array(
				'name'    => 'assets.icons.plug',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M972,289.4c-24.1-24.1-63.1-24.1-87.1,0L739.6,434.7L565.4,260.4l145.2-145.2c24.1-24.1,24.1-63.1,0-87.1S647.5,4,623.4,28L478.2,173.3l-87.1-87.1L267.7,209.5c-128,128-138.9,328.3-33.4,469.1L28,884.8C4,908.9,4,947.9,28,972s63.1,24.1,87.1,0l206.2-206.2c140.8,105.4,341.1,94.6,469.1-33.4l123.4-123.4l-87.1-87.1l145.2-145.2C996,352.5,996,313.5,972,289.4z"/></svg>'
			),
			'assets.icons.content'     => array(
				'name'    => 'assets.icons.content',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M92.3,716.5h52.5v82H90c-44.2,0-80-35.8-80-79.9V91.2c0-44.1,35.8-79.9,80-79.9h655.9c44.2,0,80.1,35.8,80.1,79.9v54.8h-82.2V93.5H92.3V716.5L92.3,716.5L92.3,716.5L92.3,716.5z M990,255.4v653.5c0,44.1-35.9,79.8-80.1,79.8H254.2c-44.3,0-80.2-35.8-80.2-79.8V255.4c0-44.1,35.9-79.8,80.2-79.8H910C954.1,175.6,990,211.3,990,255.4L990,255.4L990,255.4L990,255.4z M907.8,257.6H256.3v649.1h651.4h0L907.8,257.6L907.8,257.6L907.8,257.6L907.8,257.6z M334.8,449.1h171.3c3.8,0,6.9-3.1,6.9-6.9V373v-0.9c0-3.8-3.1-7-6.8-7H334.8c-3.8,0-6.9,3.2-6.9,7v70.2C327.9,446,331,449.1,334.8,449.1L334.8,449.1L334.8,449.1L334.8,449.1z M334.8,624.4h386.6c3.8,0,6.9-3.1,6.9-6.9v-69.3c0.1-0.4,0.1-0.6,0.1-0.9c0-3.8-3-6.9-6.8-6.9H334.8c-3.8,0-6.9,3.1-6.9,6.9v70.3C327.9,621.2,331,624.4,334.8,624.4L334.8,624.4L334.8,624.4L334.8,624.4z M334.8,799.5h494.3c3.8,0,6.9-3.1,6.9-6.9v-69.3c0-0.4,0-0.6,0-0.9c0-3.8-3.1-6.9-6.8-6.9H334.8c-3.8,0-6.9,3.1-6.9,6.9v70.3C327.9,796.5,331,799.5,334.8,799.5L334.8,799.5L334.8,799.5L334.8,799.5z"/></svg>'
			),
			'assets.icons.lock'        => array(
				'name'    => 'assets.icons.lock',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M4723.9,4998.3c-722.1-61.6-1448.4-397.1-1992.1-919.6c-535.2-514-851.6-1074.6-1006.7-1779.7c-36.1-167.8-44.6-297.3-53.1-838.9l-10.6-643.5h-348.3H964.9v-2803.3V-4790H5000h4035.1v2803.3V816.7h-348.3h-348.3l-10.6,622.3c-10.6,690.2-29.7,849.5-152.9,1221.2c-189,562.8-460.9,989.7-906.8,1418.7C6582.2,4737.1,5643.5,5079.1,4723.9,4998.3z M5490.6,4371.8c584-99.8,1040.6-341.9,1463.3-770.9c269.7-274,416.2-488.5,554.3-809.2c180.5-418.4,231.5-747.6,231.5-1486.6V816.7h-507.6h-507.6l-8.5,601c-8.5,552.2-12.7,609.5-57.3,747.6c-176.3,535.2-567,959.9-1078.9,1168.1c-779.4,316.4-1718.1-78.6-2125.9-892c-148.7-299.4-159.3-365.3-169.9-1023.6l-8.5-601h-507.6h-507.6v488.5c0,269.7,10.6,581.9,23.4,694.5c133.8,1210.5,1023.6,2162,2217.2,2372.2C4738.8,4414.3,5242.1,4414.3,5490.6,4371.8z M5339.8,2798.1c390.8-106.2,698.7-452.4,764.5-855.9c10.6-76.5,21.2-361,21.2-630.8V816.7H5000H3874.4v516.1c0,363.2,10.6,556.4,31.9,658.4c78.6,373.8,356.8,681.7,722.1,800.7C4821.6,2855.5,5121.1,2857.6,5339.8,2798.1z M8440.5-1997.3v-2198.1H5000H1559.5v2198.1V200.8H5000h3440.5V-1997.3z" transform="matrix(.1 0 0 -.1 0 511)"/><path d="M4872.6-854.7c-40.4-21.2-95.6-70.1-121.1-110.4l-48.8-72.2v-957.8c0-911.1,2.1-962,42.5-1025.8c59.5-97.7,138-142.3,254.8-142.3c116.8,0,195.4,44.6,254.8,142.3c40.4,63.7,42.5,114.7,42.5,1023.6c0,909-2.1,960-42.5,1023.7C5172-835.6,5006.4-784.6,4872.6-854.7z" transform="matrix(.1 0 0 -.1 0 511)"/></svg>'
			),
			'assets.icons.obscure'     => array(
				'name'    => 'assets.icons.obscure',
				'default' => '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 1000 1000"><path d="M987.5,543.9l2.5-1.7L731.7,162.1l-4.5-1.8c-1.1-0.4-103.1-38.2-168.5,64.2l26.2,16.7c45.2-70.8,109.6-58.2,126.8-53.3l230,338.6C910.4,519.4,859.6,511,793,511c-66.1,0-134.1,8.3-202,24.8l-11.7,2.8l-0.2,14.8c-61-26.1-128.2-9.2-160.7,2.2l-0.3-17l-11.7-2.8C338.5,519.3,270.5,511,204.4,511c-62.4,0-110.9,7.4-142.6,14.1L291,187.9c17.3-5.1,81.3-17.9,126.8,53.4l26.2-16.7c-65.3-102.5-167.5-64.6-168.5-64.2l-4.5,1.8L15.5,538l-5.5,2l0.3,133.6c-0.3,2.6-5,64.7,40.7,114.4c35.9,39.1,91.8,58.9,166.1,58.9c77.6,0,134.6-19.8,169.2-58.7c40.2-45.2,34.4-99.1,34.3-99.8l-1.6-99.7c22.9-9.1,99.4-34.6,159.6-0.9l-1.6,99c-0.3,2.3-6.1,56.1,34.2,101.3c34.7,39,91.7,58.7,169.2,58.7c74.3,0,130.3-19.8,166.1-58.9c45.6-49.7,40.9-111.8,40.7-113.1L987.5,543.9z"/></svg>'
			)
		)
	),

	// List of built-in content taxonomies that user can select from -------------------
	array(
		'name'    => 'user_selectable_taxonomies',

		// list of built-in taxonomies
		'content' => array(
			'taxonomies.built_in_selectable' => array(
				'name'    => 'taxonomies.built_in_selectable',
				'default' => array(
					'post' => array( 'category', 'post_tag' ),
					'page' => array(),
				),
			)
		)
	),

	// Max number of items allowed in a taxonomy to allow user-selection ---------------
	array(
		'name'    => 'max_user_selectable_taxonomies',

		// max number of items
		'content' =>  array(
			'taxonomies_max_user_selectable' => array(
				'name'    => 'taxonomies_max_user_selectable',
				'default' => 50
			)
		)
	),

	// List of transients used ---------------------------------------------------------
	array(
		'name'    => 'transients_ttl',

		// options in transients group
		'content' => array(
			'ttl.weeblramp_fe_rendered_menus' => array(
				'name'    => 'ttl.weeblramp_fe_rendered_menus',
				'default' => 24 * HOUR_IN_SECONDS
			),
			'ttl.remote_config_amp'           => array(
				'name'    => 'ttl.remote_config_amp',
				'default' => 12 * HOUR_IN_SECONDS
			),
			'ttl.remote_config_ampform'       => array(
				'name'    => 'ttl.remote_config_ampform',
				'default' => 12 * HOUR_IN_SECONDS
			)
		)
	),

	// Dimensions ----------------------------------------------------------------------
	array(
		'name'    => 'dimensions',

		// size of things
		'content' => array(
			'sizes.item_header_author_avatar_default_size' => array(
				'name'    => 'sizes.item_header_author_avatar_default_size',
				'default' => 24
			),
			'sizes.item_author_bio_avatar_default_size'    => array(
				'name'    => 'sizes.item_author_bio_avatar_default_size',
				'default' => 48
			),
			'sizes.pagination_links_abridged_length'       => array(
				'name'    => 'sizes.pagination_links_abridged_length',
				'default' => 35
			),
			'sizes.pagination_links_abridged_intro'        => array(
				'name'    => 'sizes.pagination_links_abridged_intro',
				'default' => 15
			),
			'sizes.social_buttons_width'                   => array(
				'name'    => 'sizes.social_buttons_width',
				'default' => 48
			),
			'sizes.social_buttons_height'                  => array(
				'name'    => 'sizes.social_buttons_height',
				'default' => 48
			),
		)
	),

	// List of external URLs -----------------------------------------------------------
	array(
		'name'    => 'urls',

		// options in urls group
		'content' => array(
			'urls.documentation_server'          => array(
				'name'    => 'urls.documentation_server',
				'default' => 'https://www.weeblrpress.com',
			),
			'urls.documentation_embed_url'       => array(
				'name'    => 'urls.documentation_embed_url',
				'default' => 'https://rdoc.weeblrpress.net/index.php?option=com_wbdoc&product=products.weeblramp&version=1&view=document&tmpl=component&embed=true&Itemid=337&doc_url=',
			),
			'urls.update_download_bases'         => array(
				'name'    => 'urls.update_download_bases',
				'default' => array( 'https://u1.weeblrpress.com/dist' ),
			),
			'urls.api.prod'                      => array(
				'name'    => 'urls.api.prod',
				'default' => 'https://www.weeblrpress.com',
			),
			'urls.api.dev'                       => array(
				'name'    => 'urls.api.dev',
				'default' => 'https://weeblrpress.apps.localsrc.weeblr.net',
			),
			'urls.remote_config_amp'             => array(
				'name'    => 'urls.remote_config_amp',
				'default' => 'https://u1.weeblrpress.com/public/direct/weeblramp/config/v1/amp.cfg.json',
			),
			'urls.remote_config_ampform'         => array(
				'name'    => 'urls.remote_config_ampform',
				'default' => 'https://u1.weeblrpress.com/public/direct/weeblramp/config/v1/ampform.cfg.json',
			),
			'urls.google.amp_validator'          => array(
				'name'    => 'urls.google.amp_validator',
				'default' => 'https://search.google.com/search-console/amp?url=%s',
			),
			'urls.google.structured_data_tester' => array(
				'name'    => 'urls.google.structured_data_tester',
				'default' => 'https://search.google.com/structured-data/testing-tool/#url=%s',
			),
		)
	),

	// List of html tags to automatically process into AMP tags ------------------------
	array(
		'name'    => 'embed_tags_list',

		// options in embedTags group
		'content' => array(

			'embed_tags' => array(
				'name'    => 'embed_tags',
				'default' => array(

					// auto embeddable URLs
					'twitter'           => array(
						'url_regexp' => '#http(s|):\/\/twitter\.com(\/\#\!\/|\/)([a-zA-Z0-9_]{1,20})\/status(es)*\/(\d+)#iu',
						'script'     => 'twitter',
						'style'      => 'social',
						'amp_tag'    => 'amp-twitter'
					),
					'instagram'         => array(
						'url_regexp' => '#https?:\/\/(?:www\.)?instagr(?:\.am|am\.com)/p/([a-zA-Z0-9]+)#iu',
						'script'     => 'instagram',
						'style'      => '',
						'amp_tag'    => 'amp-instagram'
					),
					'vine'              => array(
						'url_regexp' => '#https?:\/\/vine\.co/v/([^/?]+)#iu',
						'script'     => 'vine',
						'style'      => '',
						'amp_tag'    => 'amp-vine'
					),
					'youtube'           => array(
						'url_regexp' => '#(?:http(?:s)?:\/\/)?(?:www\.)?(?:m\.)?(?:youtu\.be\/|youtube\.com\/(?:(?:watch)?\?(?:.*&)?v=|(?:embed|v|e)\/))([a-zA-Z0-9-&;=]+)#iu',
						'script'     => 'youtube',
						'style'      => '',
						'amp_tag'    => 'amp-youtube'
					),
					'dailymotion'       => array(
						'url_regexp' => '#https?:\/\/(?:www\.)?dailymotion\.com\/video\/([^_]+)#iu',
						'script'     => 'dailymotion',
						'style'      => '',
						'amp_tag'    => 'amp-dailymotion'
					),
					'facebook'          => array(
						'url_regexp' => '#https?:\/\/(?:www\.)?(?:facebook\.com\/)([^\/]+)\/(posts|videos)\/(\d+)#iu',
						'script'     => 'facebook',
						'style'      => 'social',
						'amp_tag'    => 'amp-facebook'
					),

					// AMP extended elements
					'carousel'          => array(
						'url_regexp' => '',
						'script'     => 'carousel',
						'amp_tag'    => 'amp-carousel'
					),
					'user-notification' => array(
						'url_regexp' => '',
						'script'     => 'user-notification',
						'style'      => 'notif',
						'amp_tag'    => 'amp-user-notification'
					)
				),
			),
		)
	),

);
